@@ -268,7 +268,8 @@ nlmControl <- function(typsize = NULL,
                scaleTo=scaleTo,
                gradTo=gradTo,
 
-               addProp=addProp, calcTables=calcTables,
+               addProp=match.arg(addProp),
+               calcTables=calcTables,
                compress=compress,
                solveType=solveType,
                ci=ci, sigdig=sigdig, sigdigTable=sigdigTable,
