@@ -277,7 +277,9 @@ nlminbControl <- function(eval.max=200,
                literalFix=literalFix,
                sumProd=sumProd,
                rxControl=rxControl,
-               returnNlminb=returnNlminb, addProp=addProp, calcTables=calcTables,
+               returnNlminb=returnNlminb,
+               addProp=match.arg(addProp),
+               calcTables=calcTables,
                compress=compress,
                ci=ci, sigdig=sigdig, sigdigTable=sigdigTable,
                genRxControl=.genRxControl)
