@@ -238,7 +238,7 @@ nlsControl <- function(maxiter=10000,
                sumProd=sumProd,
                rxControl=rxControl,
                returnNls=returnNls,
-               addProp=addProp,
+               addProp=match.arg(addProp),
                calcTables=calcTables,
                compress=compress,
                ci=ci, sigdig=sigdig, sigdigTable=sigdigTable,
