@@ -1,5 +1,7 @@
 nmTest({
 
+  .nlmixr2 <- function(...) {suppressWarnings(suppressMessages(nlmixr2(...)))}
+
   test_that("character estimation works", {
 
     one_compartment_textcov <- function() {
@@ -28,7 +30,7 @@ nmTest({
     fitdata <- theo_sd
     fitdata$ID <- paste("theo", fitdata$ID)
     fitdata$LowID <- ifelse(as.numeric(theo_sd$ID) < 7, "Yes", "No")
-    fit <- nlmixr2(one_compartment_textcov, fitdata,  est="focei", control = foceiControl(print = 0))
+    fit <- .nlmixr2(one_compartment_textcov, fitdata,  est="focei", control = foceiControl(print = 0))
 
     .cllow <- fit$theta["cllow"]
 
@@ -42,9 +44,9 @@ nmTest({
     expect_equal(levels(fit$LowID), c("No", "Yes"))
 
     fitdata$LowID <- factor(fitdata$LowID, c("Yes", "No"))
-    fit <- nlmixr2(one_compartment_textcov, fitdata,  est="focei", control = foceiControl(print = 0))
+    fit <- .nlmixr2(one_compartment_textcov, fitdata,  est="focei", control = foceiControl(print = 0))
 
     expect_equal(.cllow, fit$theta["cllow"])
-    
+
   })
 })
